@@ -899,11 +899,13 @@ def pbdDict_bxReposRoot(
     gitClone( 'unisos/overview',  'bx-unisos/overview', vcMode)
 
     gitCloneBase( 'bisos',  'bisos/base', vcMode)
-    gitClone( 'bisos/overview',  'bisos/overview', vcMode)
-    gitClone( 'bisos/bsip4',  'bisos/bsip4', vcMode)
-    gitClone( 'bisos/bpip1',  'bisos/bpip1', vcMode)
-    gitClone( 'bisos/comeega',  'bisos/comeega', vcMode)        
-   
+    gitClone('bisos/overview',  'bisos/overview', vcMode)
+    gitClone('bisos/bsip4',  'bisos/bsip4', vcMode)
+    gitClone('bisos/bpip1',  'bisos/bpip1', vcMode)
+    gitClone('bisos/comeega',  'bisos/comeega', vcMode)
+    gitClone('bisos/gatherer',  'bisos/gatherer', vcMode)
+    gitClone('bisos/defaults',  'bisos/defaults', vcMode)    
+    
     gitCloneBase( 'blee',  'bx-blee/base',  vcMode)
     gitClone(
         'blee/overview',
